@@ -428,8 +428,13 @@ rfbProcessClientMessage(cl)
     case RFB_SECURITY_TYPE:
 	rfbAuthProcessSecurityTypeMessage(cl);
 	return;
+#ifdef HAVE_GNUTLS
     case RFB_TLS_HANDSHAKE:
-	rfbAuthProcessTlsHandshake(cl);
+	rfbAuthProcessTLSHandshake(cl);
+	return;
+#endif
+    case RFB_AUTH_TYPE:
+	rfbAuthProcessAuthTypeMessage(cl);
 	return;
     case RFB_AUTHENTICATION:
         rfbAuthProcessClientMessage(cl);
