@@ -29,6 +29,7 @@
 #ifdef VINO_ENABLE_HTTP_SERVER
 #include "vino-http.h"
 #endif
+#include "vino-mdns.h"
 #include "vino-input.h"
 #include "vino-cursor.h"
 #include "vino-prompt.h"
@@ -580,8 +581,7 @@ vino_server_screen_size_changed (VinoServer *server)
   rfbNewFramebuffer (server->priv->rfb_screen,
 		     vino_fb_get_pixels (server->priv->fb),
 		     gdk_screen_get_width (server->priv->screen),
-		     gdk_screen_get_height (server->priv->screen),
-		     -1, -1, -1);
+		     gdk_screen_get_height (server->priv->screen));
 
   vino_server_init_pixel_format (server, server->priv->rfb_screen);
 }
@@ -645,7 +645,7 @@ vino_server_init_from_screen (VinoServer *server,
    *   we don't pass in argc or argv
    *   samplesPerPixel is totally unused (3 below)
    *   bitsPerSample and bytesPerPixel get set in
-   *   set_pixel_format()
+   *   init_pixel_format()
    */
   server->priv->rfb_screen = rfb_screen = 
     rfbGetScreen (NULL, NULL,
@@ -697,6 +697,8 @@ vino_server_init_from_screen (VinoServer *server,
 #ifdef VINO_ENABLE_HTTP_SERVER
   server->priv->http = vino_http_get (rfb_screen->rfbPort);
 #endif
+
+  vino_mdns_add_service ("_rfb._tcp", rfb_screen->rfbPort);
 }
 
 static void
